@@ -88,7 +88,7 @@ class Broker:
         self._fills = []
 
         # Slippage model
-        self._default_slippage_model = lambda n: 0
+        self._default_slippage_model = self._zero_slippage_model
         self._slippage_models = {}
 
         # Account
@@ -1698,6 +1698,11 @@ class Broker:
 
         return orderbook
 
+    @staticmethod
+    def _zero_slippage_model(*args, **kwargs):
+        "Returns zero slippage."
+        return 0
+
     def _save_state(self):
         """Pickles the current state of the broker."""
         try:
